==> voreen-src-4.1.1-win.zip: voreen-src-4.1.1-win/include/voreen/core/io/serialization/abstractserializable.h <==
/***********************************************************************************
 *                                                                                 *
 * Voreen - The Volume Rendering Engine                                            *
 *                                                                                 *
 * Copyright (C) 2005-2012 University of Muenster, Germany.                        *
 * Visualization and Computer Graphics Group <http://viscg.uni-muenster.de>        *
 * For a list of authors please refer to the file "CREDITS.txt".                   *
 *                                                                                 *
 * This file is part of the Voreen software package. Voreen is free software:      *
 * you can redistribute it and/or modify it under the terms of the GNU General     *
 * Public License version 2 as published by the Free Software Foundation.          *
 *                                                                                 *
 * Voreen is distributed in the hope that it will be useful, but WITHOUT ANY       *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR   *
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.      *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License in the file   *
 * "LICENSE.txt" along with this file. If not, see <http://www.gnu.org/licenses/>. *
 *                                                                                 *
 * For non-commercial academic use see the license exception specified in the file *
 * "LICENSE-academic.txt". To get information about commercial licensing please    *
 * contact the authors.                                                            *
 *                                                                                 *
 ***********************************************************************************/

#ifndef VRN_IABSTRACTSERIALIZABLE_H
#define VRN_IABSTRACTSERIALIZABLE_H

#include "voreen/core/io/serialization/serializable.h"

namespace voreen {

/**
 * @c AbstractSerializable is a marker interface to prevent instance creation using the defaults
 * constructor during deserialization process for abstract classes.
 *
 * @attention You have to ensure that @c Serializable respectively @c AbstractSerializable
 *            is the first class from which you derive. Otherwise there will be pointer
 *            mismatches due to type conversions.
 *
 * @see Serializable
 */
class VRN_CORE_API AbstractSerializable : public Serializable {
};

} // namespace

#endif // VRN_IABSTRACTSERIALIZABLE_H

==> voreen-src-4.2-win.zip: voreen-src-4.2-win/include/voreen/core/io/serialization/abstractserializable.h <==
/***********************************************************************************
 *                                                                                 *
 * Voreen - The Volume Rendering Engine                                            *
 *                                                                                 *
 * Copyright (C) 2005-2013 University of Muenster, Germany.                        *
 * Visualization and Computer Graphics Group <http://viscg.uni-muenster.de>        *
 * For a list of authors please refer to the file "CREDITS.txt".                   *
 *                                                                                 *
 * This file is part of the Voreen software package. Voreen is free software:      *
 * you can redistribute it and/or modify it under the terms of the GNU General     *
 * Public License version 2 as published by the Free Software Foundation.          *
 *                                                                                 *
 * Voreen is distributed in the hope that it will be useful, but WITHOUT ANY       *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR   *
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.      *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License in the file   *
 * "LICENSE.txt" along with this file. If not, see <http://www.gnu.org/licenses/>. *
 *                                                                                 *
 * For non-commercial academic use see the license exception specified in the file *
 * "LICENSE-academic.txt". To get information about commercial licensing please    *
 * contact the authors.                                                            *
 *                                                                                 *
 ***********************************************************************************/

#ifndef VRN_ABSTRACTSERIALIZABLE_H
#define VRN_ABSTRACTSERIALIZABLE_H

#include "voreen/core/io/serialization/serializable.h"

namespace voreen {

/**
 * @c AbstractSerializable is a marker interface to prevent instance creation using the defaults
 * constructor during deserialization process for abstract classes.
 *
 * @attention You have to ensure that @c Serializable respectively @c AbstractSerializable
 *            is the first class from which you derive. Otherwise there will be pointer
 *            mismatches due to type conversions.
 *
 * @see Serializable
 */
class VRN_CORE_API AbstractSerializable : public Serializable {
};

} // namespace

#endif // VRN_ABSTRACTSERIALIZABLE_H
